__title__ = 'pypay'
__version__ = '0.2.1'
__version_info__ = tuple(__version__.split('.'))
__author__ = 'Judd Garratt'
__license__ = 'Apache 2.0'
__copyright__ = 'Copyright 2017 Judd Garratt'

from .api import pdt_confirm, ipn_confirm
